function wrapper() {
    function bar__2(props__3) {}
    var Foo__2 = function Foo1__4() {
        _classCallCheck(this, Foo1__4);
        super();
        _defineProperty(this, 'onBar', ()=>{
            bar__2();
        });
        bar__2();
    };
}
